@@ -38,8 +38,8 @@ cpus = defaults.cpus
 
 
 def save_nb(verbose=False):
-    display(Javascript('IPython.notebook.save_checkpoint()'))
-    time.sleep(1)
+    display(Javascript('IPython.notebook.save_checkpoint();'))
+    time.sleep(3)
     pv('\nCurrent notebook saved.\n', verbose)
 
 
@@ -86,4 +86,17 @@ def create_scripts(max_elapsed=60):
     from nbdev.export import notebook2script
     save_nb()
     notebook2script()
-    return last_saved(max_elapsed)
\ No newline at end of file
+    return last_saved(max_elapsed)
+
+
+class Timer():
+    def __init__(self): self.start_dt = None
+    def start(self): self.start_dt = datetime.now()
+    def stop(self):
+        end_dt = datetime.now()
+        elapsed = end_dt - self.start_dt
+        print(f'Elapsed time: {elapsed}')
+        self.start_dt = datetime.now()
+        return elapsed
+
+timer = Timer()
\ No newline at end of file
